﻿#define lefttitlecorrection // uncomment this #define to run Left Axis Title correction routines
using Microsoft.Maui;
using Microsoft.Maui.Converters;
using Steema.TeeChart;
using Steema.TeeChart.Drawing;
using Steema.TeeChart.Maui;
using Steema.TeeChart.Styles;

namespace TeeChartMockUpDemos
{
    public partial class LineChart : ContentPage
    {
        public LineChart()
        {
            InitializeComponent();
            view3D.CheckedChanged += View3D_CheckedChanged;
            var line = new Line(tChart1.Chart);
            line.FillSampleValues();
            var line2 = new Line(tChart1.Chart);
            line2.FillSampleValues();
            var line3 = new Line(tChart1.Chart);
            line3.FillSampleValues();
            ZoomMode.IsVisible = false;
            tChart1.Chart.Legend.Visible = false;
            tChart1.Panning.Active = false;
            tChart1.Panning.Allow = ScrollModes.Horizontal;
            tChart1.Zoom.Active = true;
            tChart1.Zoom.Direction = ZoomDirections.Horizontal;
            // MouseButtons.Right doesn't work because all mouse clicks are reported as left clicks (see MouseEventsArgs in Chart_ClickBackground below)
            tChart1.Zoom.MouseButton = MouseButtons.Left;
            tChart1.Zoomed += TChart1OnZoomed;
            tChart1.BeforeDraw += TChart1OnBeforeDraw;
            tChart1.Chart.ClickBackground += Chart_ClickBackground;
#if lefttitlecorrection
            tChart1.Chart.Axes.Left.Title.AutoPosition = false;
            tChart1.Chart.Axes.Left.Title.Caption = "Left Title";
            tChart1.Chart.Axes.Left.Title.Visible = true;
            SetLeftTitle();
#endif
        }

        private void Chart_ClickBackground(object sender, MouseEventArgs e)
        {
            // if debug breakpoint is put after the following line of code you can see that no matter which mouse button is clicked it is always reported as a left click
            var button = e.Button;
        }

        private void View3D_CheckedChanged(object sender, CheckedChangedEventArgs e)
        {
            tChart1.Chart.Aspect.View3D = e.Value;
        }

        private void TChart1OnZoomed(object sender, EventArgs e)
        {
            // this routine automatically switches to panning mode when the chart is zoomed
            // note that when panning after the first time, the panning function loses track of where it is, resulting in incorrect pans with the chart jumping around when clicked for a pan
            tChart1.Zoom.Active = false;
            tChart1.Panning.Active = true;
            ZoomMode.IsVisible = true;
        }

        private void ZoomMode_OnClicked(object sender, EventArgs e)
        {
            // had to add this reenable zoom because right click doesn't work, preventing zoom and panning functions to be enabled at the same time
            tChart1.Panning.Active = false;
            tChart1.Zoom.Active = true;
            ZoomMode.IsVisible = false;
        }

        private int _titleLeft = 0;
        private int _titleTop = 0;
        private void SetLeftTitle()
        {
            // this routine manually sets the left axis title. It is necessary for all platforms
            // note that the Left and Top functions seem to be reversed
            _titleLeft = tChart1.Chart.Axes.Left.Title.Left = - (int) tChart1.Height / 2;
            _titleTop = tChart1.Chart.Axes.Left.Title.Top = 10;
        }

        private void TChart1OnBeforeDraw(object sender, IGraphics3D g)
        {
            // the following restores correct Left Title values that were changed by a previous draw function (zooming forces a redraw) when Left Title location has been manually set
            // the following lines of code have no effect unless tChart1.Chart.Axes.Left.Title.AutoPosition is set to false
            // in some cases both Left and Top values are changed dy a redraw (not in this test app)
            // place a breakpoint here, before the following lines of code are executed, to examine the values of the Left Title location values versus manually set values (_titleLeft and _titleRight settings)
            tChart1.Chart.Axes.Left.Title.Left = _titleLeft;
            tChart1.Chart.Axes.Left.Title.Top = _titleTop;
        }

        private void LineChart_OnLoaded(object sender, EventArgs e)
        {
            if (DeviceInfo.Platform.ToString() == "WinUI")
            {
                Window.SizeChanged += WindowOnSizeChanged;
                SetLeftTitle();
            }
        }

        private void WindowOnSizeChanged(object sender, EventArgs e)
        {
            SetLeftTitle();
        }
    }
}
